@@ -434,7 +434,9 @@ void Mission::SetLocale( const string &lang ) {
   p2.SetName( messages.GetMsg(p2.NameID()) );
 
   for ( Building *b = static_cast<Building *>(shops.Head());
-        b; b = static_cast<Building *>(b->Next()) )
-    b->SetName( messages.GetMsg(b->NameID()) );
+        b; b = static_cast<Building *>(b->Next()) ) {
+    const char *name = messages.GetMsg(b->NameID());
+    b->SetName( name != NULL ? name : "" );
+  }
 }
 
