@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2006 Jens Granseuer
+// Copyright (C) 2002-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -201,7 +201,8 @@ GUI_Status EdWindow::HandleEvent( const SDL_Event &event ) {
       // handle just like a mouse button if LMB is down and
       // user is terraforming
       if ( (mode == ED_MODE_TERRAIN) &&
-           (event.motion.state & SDL_BUTTON( SDL_BUTTON_LEFT )) ) {
+           (event.motion.state & SDL_BUTTON( SDL_BUTTON_LEFT )) &&
+           !ud_wd->Clicked() && !lr_wd->Clicked() ) {
         Point pos;
         if ( !mv.Pixel2Hex( event.motion.x, event.motion.y, pos ) )
           LeftMouseButton( pos );
