@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -60,9 +60,9 @@ void ButtonWidget::Draw( void ) {
   if ( (flags & WIDGET_STYLE_MENU) && Clicked() ) {
     surface->DrawBox( *this, BOX_RECESSED );
     surface->FillRectAlpha( x+1, y+1, w-2, h-2, Color(CF_COLOR_SHADOW) );
-  } else if ( flags & WIDGET_STYLE_HIGHLIGHT )
+  } else if ( flags & WIDGET_STYLE_HIGHLIGHT ) {
     surface->FillRectAlpha( *this, surface->GetFGPen() );
-  else if ( !(flags & WIDGET_STYLE_NOBORDER) ) {
+  } else if ( !(flags & WIDGET_STYLE_NOBORDER) ) {
     surface->DrawBox( *this, BOX_RECESSED );
     surface->DrawBox( Rect(x+1,y+1,w-2,h-2), Clicked() ? BOX_RECESSED : BOX_RAISED );
     if ( Clicked() )
@@ -71,7 +71,19 @@ void ButtonWidget::Draw( void ) {
 
   if ( flags & WIDGET_STYLE_GFX ) {
     Image &img = image[Clicked()];
-    img.Draw( surface, x + (w - img.Width()) / 2, y + (h - img.Height()) / 2 );
+
+    // the flags designate the label alignment; image alignment is opposite
+    int xoff;
+    if ( (flags & (WIDGET_ALIGN_LEFT|WIDGET_ALIGN_WITHIN)) ==
+         (WIDGET_ALIGN_LEFT|WIDGET_ALIGN_WITHIN) ) {
+      xoff = x + (w - img.Width()) - 2;
+    } else if ( (flags & (WIDGET_ALIGN_RIGHT|WIDGET_ALIGN_WITHIN)) ==
+         (WIDGET_ALIGN_RIGHT|WIDGET_ALIGN_WITHIN) ) {
+      xoff = x + 2;
+    } else {
+      xoff = x + (w - img.Width()) / 2;
+    }
+    img.Draw( surface, xoff, y + (h - img.Height()) / 2 );
   }
 
   PrintTitle( ((flags & WIDGET_STYLE_HIGHLIGHT) && !Clicked()) ?
@@ -97,7 +109,7 @@ void ButtonWidget::SetImage( Surface *image,
                              const Rect &state1, const Rect &state2 ) {
   this->image[0] = Image( image, state1.x, state1.y, state1.w, state1.h );
   this->image[1] = Image( image, state2.x, state2.y, state2.w, state2.h );
-} 
+}
 
 ////////////////////////////////////////////////////////////////////////
 // NAME       : ButtonWidget::MouseDown
@@ -421,7 +433,7 @@ GUI_Status CycleWidget::MouseDown( const SDL_MouseButtonEvent &button ) {
 ////////////////////////////////////////////////////////////////////////
 
 GUI_Status CycleWidget::MouseUp( const SDL_MouseButtonEvent &button ) {
-  if ( Clicked() && 
+  if ( Clicked() &&
        ((button.button == SDL_BUTTON_LEFT) ||
         (button.button == SDL_BUTTON_RIGHT)) ) {
     bool hit = Contains( button.x - surface->LeftEdge(),
