@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -27,6 +27,14 @@
 # include <sys/stat.h>
 #endif
 
+#ifdef WIN32
+# include <windows.h>
+# include <shlobj.h>
+# ifndef _WIN32_WCE
+#  include <shellapi.h>
+# endif
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -355,7 +363,7 @@ void make_dir( const char *dir ) {
 ////////////////////////////////////////////////////////////////////////
 // NAME       : create_config_dir
 // DESCRIPTION: Create a configuration and save directory in the user's
-//              home dir (UNIX & Co.) or the crimson program directory
+//              home dir (UNIX & Co.) or his My Documents folder
 //              (Win32).
 // PARAMETERS : -
 // RETURNS    : -
@@ -384,18 +392,14 @@ void create_config_dir( void ) {
 
 string get_home_dir( void ) {
 #ifdef WIN32
-# ifdef _WIN32_WCE
-  return "";
+  TCHAR dir[MAX_PATH];
+  SHGetSpecialFolderPath( NULL, dir, CSIDL_PERSONAL, TRUE );
+# ifdef UNICODE
+  char mbdir[MAX_PATH];
+  wcstombs( mbdir, dir, wcslen(dir)+1 );
+  return mbdir;
 # else
-  char dir[MAX_PATH];
-  int length = GetEnvironmentVariable("HOME", dir, MAX_PATH);
-  if ( length == 0 ) {
-    length = GetEnvironmentVariable("HOMEDRIVE", dir, MAX_PATH);
-    length += GetEnvironmentVariable("HOMEPATH", dir + length, MAX_PATH - length);
-  }
-
-  if ( length == 0 ) return "";
-  else return dir;
+  return dir;
 # endif
 #elif defined __BEOS__
   return "./";
